@@ -138,7 +138,7 @@ class NerVisualizer:
 
         return html_output
 
-    def display(self, result, label_col, document_col='document', raw_text=None, labels=None, return_html=False):
+    def display(self, result, label_col, document_col='document', raw_text=None, labels=None, return_html=False, save_path=None):
         """Displays NER visualization. 
         Inputs:
         result -- A Dataframe or dictionary.
@@ -153,8 +153,15 @@ class NerVisualizer:
         
         html_content = self.__display_ner(result, label_col, document_col, raw_text, labels)
         
+        html_content_save = style_config.STYLE_CONFIG_ENTITIES+ " "+html_content
+        
+        if save_path != None:
+            with open(save_path, 'w') as f_:
+                f_.write(html_content_save)
+        
         if return_html:
-            return style_config.STYLE_CONFIG_ENTITIES+ " "+html_content
+            return html_content_save
         else:
-            return display(HTML(style_config.STYLE_CONFIG_ENTITIES+ " "+html_content))
+            return display(HTML(html_content_save))
+        
         
\ No newline at end of file
